==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/flipgroup/data_flipgroup_list/maint.tf <==
/*
Пример использования
Получение информации о сети
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_flipgroup_list" "fg" {
  #фильтр по id flipgroup
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени flipgroup
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id vins
  #опциональный параметр
  #тип - целое число
  #vins_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #vins_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - целое число
  #extnet_id = 100

  #фильтр по IP
  #опциональный параметр
  #тип - строка
  #by_ip = "1.1.1.1.1"

  #id ресурсной группы, используется для фильтрации
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #rg_id = 11111

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - целое число
  #account_id = 100

  #фильтр по id conn
  #опциональный параметр
  #тип - целое число
  #conn_id = 100

  #фильтр по id клиентов
  #опциональный параметр
  #тип - массив целых чисел
  #client_ids = [10,11]

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "CREATED"
}

output "test" {
  value = data.dynamix_flipgroup_list.fg
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/flipgroup/data_flipgroup_list/maint.tf <==
/*
Пример использования
Получение информации о сети
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_flipgroup_list" "fg" {
  #фильтр по id flipgroup
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени flipgroup
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id vins
  #опциональный параметр
  #тип - целое число
  #vins_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #vins_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - целое число
  #extnet_id = 100

  #фильтр по IP
  #опциональный параметр
  #тип - строка
  #by_ip = "1.1.1.1.1"

  #id ресурсной группы, используется для фильтрации
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #rg_id = 11111

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - целое число
  #account_id = 100

  #фильтр по id conn
  #опциональный параметр
  #тип - целое число
  #conn_id = 100

  #фильтр по id клиентов
  #опциональный параметр
  #тип - массив целых чисел
  #client_ids = [10,11]

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "CREATED"
}

output "test" {
  value = data.dynamix_flipgroup_list.fg
}
